@@ -12,9 +12,15 @@ File::Stat::ModeString - conversion file stat(2) mode to/from string representat
  $st_mode = string_to_mode  ( $string  );
  $type    = mode_to_typechar( $st_mode );
 
+ $record = <IN>; chomp $record;
+ $record_re = MODE_STRING_RE;
+ $record =~ m/^some_prefix\s+$record_re\s+some_suffix$/o
+	or die "invalid record format";
+
  die "Invalid mode in $string"
 	if is_mode_string_valid( $string );
 
+
 =head1 DESCRIPTION
 
 This module provides a few functions for conversion between
@@ -25,8 +31,6 @@ All of them use only symbolic constants for mode bits
 from B<File::Stat::Bits>.
 
 
-=head1 FUNCTIONS
-
 =cut
 
 use strict;
@@ -41,11 +45,11 @@ BEGIN
 	@type_to_char %char_to_typemode %ugorw_to_mode %ugox_to_mode
 	@perms_clnid @perms_setid @perms_stick);
 
-    $VERSION = do { my @r = (q$Revision: 0.16 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+    $VERSION = do { my @r = (q$Revision: 0.17 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
     @ISA = ('Exporter');
 
-    @EXPORT = qw( &is_mode_string_valid
+    @EXPORT = qw( &is_mode_string_valid MODE_STRING_RE
 		  &mode_to_typechar &mode_to_string &string_to_mode
 		);
 
@@ -111,6 +115,21 @@ BEGIN
 }
 
 
+=head1 CONSTANTS
+
+=head2 MODE_STRING_RE
+
+Regular expression to match mode string (without ^$).
+
+=cut
+
+use constant MODE_STRING_RE => scalar
+	'[-dcbpls]([r-][w-][xsS-]){2}?[r-][w-][xtT-]';
+
+
+
+=head1 FUNCTIONS
+
 =head2
 
 is_mode_string_valid( $string )
@@ -122,7 +141,8 @@ sub is_mode_string_valid
 {
     my $string = shift;
 
-    return $string =~ m/^[-dcbpls]([r-][w-][xsS-]){2}?[r-][w-][xtT-]$/;
+    my $re = MODE_STRING_RE;
+    return $string =~ m/^$re$/o;
 }
 
 
